@@ -21,9 +21,8 @@
 #' See example below.
 
 #' @return tibble (table data.frame) object of the chosen rectangular data file will be returned.
-
+#' @seealso [picko] for more convenient use for Korean users.
 #' @examples
-
 #' # Choosing file and saving it into a variable
 #' ## Scenario 1: Picking up a file using interactive GUI dialog box:
 #' if(interactive()) {
@@ -50,22 +49,24 @@
 pick <-
 function(file = NULL, mode = NULL, ...) {   # Function starts:
 
-	if(!is.null(mode)) {
-		if(mode == "ko1") {
-			Sys.setlocale("LC_ALL", "Korean")
-			options(encoding="CP949")
-		} else if(mode == "ko2") {
-			Sys.setlocale("LC_ALL", "Korean")
-			options(encoding="UTF-8")
-		}
-	}
-
 	if (is.null(file)) {
 		fullFile <- file.choose()
 	} else {
 		fullFile <- file
 	}
 
+	if(!is.null(mode)) {
+		if(mode == "ko1") {
+			Sys.setlocale("LC_ALL", "Korean")
+			options(encoding="CP949")
+			fullFile <- iconv(fullFile, from="UTF-8", to="CP949")
+		} else if(mode == "ko2") {
+			Sys.setlocale("LC_ALL", "Korean")
+			options(encoding="UTF-8")
+			fullFile <- iconv(fullFile, from="UTF-8", to="CP949")
+		}
+	}
+
 	fileExt <- tools::file_ext(fullFile)
 
 	switch(fileExt, 
@@ -73,8 +74,8 @@ function(file = NULL, mode = NULL, ...) {   # Function starts:
 		"csv2" = readr::read_csv2(file = fullFile, ...), 
 		"tsv" = readr::read_tsv(file = fullFile, ...), 
 		"txt" = tibble::rowid_to_column(tibble::tibble(text = readr::read_file(fullFile, ...)), "paragraph"), 
-		"xlsx" = readxl::read_excel(fullFile, ...), 
-		"xls" = readxl::read_excel(fullFile, ...), 
+		"xlsx" = if(length(readxl::excel_sheets(path=fullFile)) > 1) {lapply(readxl::excel_sheets(path=fullFile), readxl::read_excel, path=fullFile, ...)} else {readxl::read_excel(fullFile, ...)}, 
+		"xls" = if(length(readxl::excel_sheets(path=fullFile)) > 1) {lapply(readxl::excel_sheets(path=fullFile), readxl::read_excel, path=fullFile, ...)} else {readxl::read_excel(fullFile, ...)}, 
 		"json" = tibble::tibble(jsonlite::fromJSON(fullFile, ...)), 
 		"rdata" = load(file = fullFile, ...), 
 		"rda" = tibble::tibble(load(file = fullFile, ...)), 
@@ -91,7 +92,8 @@ function(file = NULL, mode = NULL, ...) {   # Function starts:
 		"rtf" = tibble::rowid_to_column(tibble::tibble(text = textreadr::read_rtf(fullFile, ...)), "paragraph"), 
 		"doc" = tibble::rowid_to_column(tibble::tibble(text = textreadr::read_doc(fullFile, ...)), "paragraph"), 
 		"docx" = tibble::rowid_to_column(tibble::tibble(text = textreadr::read_docx(fullFile, ...)), "paragraph"), 
-		stop("Sorry, but the file you have just chosen is not supported in this function. Report on this issue to the author (JooYoung Seo) at https://github.com/jooyoungseo/ezpickr/issues. :)")
+		stop("Sorry, but the file you have just chosen is not supported in this function. Report on this issue to the author (JooYoung Seo) at \n
+		https://github.com/jooyoungseo/ezpickr/issues. :)")
 	)
 }   # Function ends.
 
